@@ -1,60 +1,106 @@
+import logging
 from datetime import datetime
 from typing import List
 
+import deprecation
+
+from .base import DataModel  # noqa: F401
+from .data_models.battery import Battery
 from .data_models.chore import Chore
-from .data_models.meal_items import RecipeItem, MealPlanItem
-from .data_models.product import Product, Group, ShoppingListProduct
+from .data_models.generic import EntityType
+from .data_models.meal_items import MealPlanItem, RecipeItem
+from .data_models.product import Group, Product, ShoppingListProduct
 from .data_models.task import Task
-from .grocy_api_client import (
-    DEFAULT_PORT_NUMBER,
-    GrocyApiClient,
-    TransactionType,
-)
+from .data_models.user import User  # noqa: F401
+from .errors import GrocyError  # noqa: F401
+from .grocy_api_client import ChoreDetailsResponse  # noqa: F401
+from .grocy_api_client import CurrentChoreResponse  # noqa: F401
+from .grocy_api_client import CurrentStockResponse  # noqa: F401
+from .grocy_api_client import LocationData  # noqa: F401
+from .grocy_api_client import MealPlanResponse  # noqa: F401
+from .grocy_api_client import MissingProductResponse  # noqa: F401
+from .grocy_api_client import ProductDetailsResponse  # noqa: F401
+from .grocy_api_client import RecipeDetailsResponse  # noqa: F401
+from .grocy_api_client import ShoppingListItem  # noqa: F401
+from .grocy_api_client import TaskResponse  # noqa: F401
+from .grocy_api_client import UserDto  # noqa: F401
+from .grocy_api_client import DEFAULT_PORT_NUMBER, GrocyApiClient, TransactionType
+
+_LOGGER = logging.getLogger(__name__)
+_LOGGER.setLevel(logging.INFO)
 
 
 class Grocy(object):
     def __init__(
-        self, base_url, api_key, port: int = DEFAULT_PORT_NUMBER, verify_ssl=True
+        self,
+        base_url,
+        api_key,
+        port: int = DEFAULT_PORT_NUMBER,
+        verify_ssl=True,
+        debug=False,
     ):
-        self._api_client = GrocyApiClient(base_url, api_key, port, verify_ssl)
+        self._api_client = GrocyApiClient(base_url, api_key, port, verify_ssl, debug)
+
+        if debug:
+            _LOGGER.setLevel(logging.DEBUG)
 
     def stock(self) -> List[Product]:
         raw_stock = self._api_client.get_stock()
         stock = [Product(resp) for resp in raw_stock]
         return stock
 
+    @deprecation.deprecated(details="Use due_products instead")
     def expiring_products(self, get_details: bool = False) -> List[Product]:
-        raw_expiring_product = self._api_client.get_volatile_stock().expiring_products
-        expiring_product = [Product(resp) for resp in raw_expiring_product]
+        return self.due_products(get_details)
+
+    def due_products(self, get_details: bool = False) -> List[Product]:
+        raw_due_products = self._api_client.get_volatile_stock().due_products
+        due_products = [Product(resp) for resp in raw_due_products]
 
         if get_details:
-            for item in expiring_product:
+            for item in due_products:
                 item.get_details(self._api_client)
-        return expiring_product
+        return due_products
+
+    def overdue_products(self, get_details: bool = False) -> List[Product]:
+        raw_overdue_products = self._api_client.get_volatile_stock().overdue_products
+        overdue_products = [Product(resp) for resp in raw_overdue_products]
+
+        if get_details:
+            for item in overdue_products:
+                item.get_details(self._api_client)
+        return overdue_products
 
     def expired_products(self, get_details: bool = False) -> List[Product]:
-        raw_expired_product = self._api_client.get_volatile_stock().expired_products
-        expired_product = [Product(resp) for resp in raw_expired_product]
+        raw_expired_products = self._api_client.get_volatile_stock().expired_products
+        expired_products = [Product(resp) for resp in raw_expired_products]
 
         if get_details:
-            for item in expired_product:
+            for item in expired_products:
                 item.get_details(self._api_client)
-        return expired_product
+        return expired_products
 
     def missing_products(self, get_details: bool = False) -> List[Product]:
-        raw_missing_product = self._api_client.get_volatile_stock().missing_products
-        missing_product = [Product(resp) for resp in raw_missing_product]
+        raw_missing_products = self._api_client.get_volatile_stock().missing_products
+        missing_products = [Product(resp) for resp in raw_missing_products]
 
         if get_details:
-            for item in missing_product:
+            for item in missing_products:
                 item.get_details(self._api_client)
-        return missing_product
+        return missing_products
 
     def product(self, product_id: int) -> Product:
         resp = self._api_client.get_product(product_id)
         if resp:
             return Product(resp)
 
+    def all_products(self) -> List[Product]:
+        raw_products = self.get_generic_objects_for_type(EntityType.PRODUCTS)
+        from pygrocy.grocy_api_client import ProductData
+
+        product_datas = [ProductData(product) for product in raw_products]
+        return [Product(product) for product in product_datas]
+
     def chores(self, get_details: bool = False) -> List[Chore]:
         raw_chores = self._api_client.get_chores()
         chores = [Chore(chore) for chore in raw_chores]
@@ -153,7 +199,7 @@ class Grocy(object):
         resp = self._api_client.get_task(task_id)
         return Task(resp)
 
-    def complete_task(self, task_id, done_time):
+    def complete_task(self, task_id, done_time: datetime = datetime.now()):
         return self._api_client.complete_task(task_id, done_time)
 
     def meal_plan(self, get_details: bool = False) -> List[MealPlanItem]:
@@ -170,9 +216,28 @@ class Grocy(object):
         if recipe:
             return RecipeItem(recipe)
 
-    def add_generic(self, entity_type, data):
-        return self._api_client.add_generic(entity_type, data)
+    def batteries(self) -> List[Battery]:
+        raw_batteries = self._api_client.get_batteries()
+        return [Battery(bat) for bat in raw_batteries]
 
-    def delete_entity(self, entity_type, entity_id):
-        return self._api_client.delete_entity(entity_type, entity_id)
+    def battery(self, battery_id: int) -> Battery:
+        battery = self._api_client.get_battery(battery_id)
+        if battery:
+            return Battery(battery)
 
+    def charge_battery(self, battery_id: int, tracked_time: datetime = datetime.now()):
+        return self._api_client.charge_battery(battery_id, tracked_time)
+
+    def add_generic(self, entity_type: EntityType, data):
+        return self._api_client.add_generic(entity_type.value, data)
+
+    def update_generic(self, entity_type: EntityType, object_id: int, updated_data):
+        return self._api_client.update_generic(
+            entity_type.value, object_id, updated_data
+        )
+
+    def delete_generic(self, entity_type: EntityType, object_id: int):
+        return self._api_client.delete_generic(entity_type, object_id)
+
+    def get_generic_objects_for_type(self, entity_type: EntityType):
+        return self._api_client.get_generic_objects_for_type(entity_type.value)
