@@ -1,7 +1,8 @@
+from datetime import datetime
+
 import iso8601
 import pytz
 from tzlocal import get_localzone
-from datetime import datetime
 
 
 def parse_date(input_value):
@@ -28,6 +29,16 @@ def parse_float(input_value, default_value=None):
         return default_value
 
 
+def parse_bool_int(input_value):
+    if input_value is None:
+        return False
+    try:
+        num = int(input_value)
+        return bool(num)
+    except ValueError:
+        return False
+
+
 def localize_datetime(timestamp: datetime) -> datetime:
     if timestamp.tzinfo is not None:
         return timestamp
